@@ -352,10 +352,13 @@ class iso_function():
             if any(points):
                 final_sp = multiple_intersect(points) 
                 if not any(final_sp):
-                    final_sp = [list(set(x[0]).intersection(set(x[1]))) for x in combinations(points,rep_agree)]
-                    final_sp = np.unique(reduce(lambda x,y: x+y, final_sp))
-                    if not any(final_sp):
-                        final_sp = []
+                    if rep_agree==1:
+                        final_sp=[]
+                    else:
+                        final_sp = [list(set(x[0]).intersection(set(x[1]))) for x in combinations(points,rep_agree)]
+                        final_sp = np.unique(reduce(lambda x,y: x+y, final_sp))
+                        if not any(final_sp):
+                            final_sp = []
             
 
                 final_sp = np.sort(final_sp)
@@ -445,8 +448,14 @@ class iso_function():
 
                 for bp in range(1, len(tmp_sw)-1):
                     #if len(switch_points) != bp+1:
-                    iso1_pval = mannwhitneyu(arr1[:,tmp_sw[bp-1]:tmp_sw[bp]].reshape(1,-1)[0], arr1[:,tmp_sw[bp]:tmp_sw[bp+1]].reshape(1,-1)[0])
-                    iso2_pval = mannwhitneyu(arr2[:,tmp_sw[bp-1]:tmp_sw[bp]].reshape(1,-1)[0], arr2[:,tmp_sw[bp]:tmp_sw[bp+1]].reshape(1,-1)[0])
+                    try:
+                        ##if the exp before switch is zero expressions
+                        iso1_pval = mannwhitneyu(arr1[:,tmp_sw[bp-1]:tmp_sw[bp]].reshape(1,-1)[0], arr1[:,tmp_sw[bp]:tmp_sw[bp+1]].reshape(1,-1)[0])
+                        iso2_pval = mannwhitneyu(arr2[:,tmp_sw[bp-1]:tmp_sw[bp]].reshape(1,-1)[0], arr2[:,tmp_sw[bp]:tmp_sw[bp+1]].reshape(1,-1)[0])
+                    except:
+                        iso1_pval=[1,1]
+                        iso2_pval=[1,1]
+                        
                     thisdiff = np.mean([abs(np.mean(arr1[:,tmp_sw[bp-1]:tmp_sw[bp]]) - np.mean(arr1[:,tmp_sw[bp]:tmp_sw[bp+1]])), abs(np.mean(arr2[:,tmp_sw[bp-1]:tmp_sw[bp]]) - np.mean(arr2[:,tmp_sw[bp]:tmp_sw[bp+1]]))])
                     thisenrich = self._event_enrichness(normdf, tmp_sw[bp], arr1, arr2)
                     iso_prob = ((np.sum(arr1[:,tmp_sw[bp-1]:tmp_sw[bp]].reshape(1,-1)[0]>arr2[:,tmp_sw[bp-1]:tmp_sw[bp]].reshape(1,-1)[0]))/arr1[:,tmp_sw[bp-1]:tmp_sw[bp]].reshape(1,-1)[0].shape[0]) + ((np.sum(arr1[:,tmp_sw[bp]:tmp_sw[bp+1]].reshape(1,-1)[0]<arr2[:,tmp_sw[bp]:tmp_sw[bp+1]].reshape(1,-1)[0]))/(arr1[:,tmp_sw[bp]:tmp_sw[bp+1]].reshape(1,-1)[0].shape[0]))
@@ -520,7 +529,6 @@ class iso_function():
                 ##finding switch points, correlation
                
                 iso_ratio[maj, x], allsp, final_sp, corr_list[maj, x] = self._iso_switch_between_arrays(arr1, arr2, orgarr1, orgarr2)
-          
                 ##calculate diff. value, p-values
                 iso_diff_value[maj, x], maj_pval[maj, x], min_pval[maj, x], bs, enrichness[maj,x], iso_prob[maj, x] = self._diff_before_after_switch(thisnormdf, arr1, arr2, allsp, final_sp)
                 
@@ -628,18 +636,6 @@ class iso_function():
             thisnormdf = values['normarr']
             thisexp = values['array']
 
-            
-            # maj = np.argmax(np.median(np.median(thisexp, axis=0), axis=1))
-            # secondmaj = None
-            # if thisnormdf.shape[1] > 2:
-            #     ##get second maj isoform
-            #     secondmaj = np.argsort(np.median(np.median(thisexp, axis=0), axis=1))[-2]
-
-            # self.normdf[gene]['majs'].append(maj)
-            # self.normdf[gene]['majs'].append(secondmaj)
-            #calculate correlations
-            #corrmat= self.correlation_coef(thisnormdf, maj)
-
             #calculate isoform ratio
             res_maj = self._isoform_differential_usage(thisnormdf, thisexp)
 
@@ -672,23 +668,9 @@ class iso_function():
 
                             if diff_domain == True:
                                 iso_pairs_id['exclusive_domains'].append(self._exclusive_domain(self.transcript_id[idxs[ids1]],self.transcript_id[idxs[ids2]]))
-                            # iso_dict_info[self.isoform_id[idxs[res_maj[3]]]] = (gene, res_maj[3])
-                            # iso_dict_info[self.isoform_id[idxs[ids]]] = (gene, ids)
 
 
             else:
-                 #p-values is calculated 
-                # for ids, iso_ratio in enumerate(res_maj[0]):
-                #     if iso_ratio >0 :
-                #         iso_pairs_id['gene'].append(gene)
-                #         iso_pairs_id['major_transcript'].append(self.transcript_id[idxs[res_maj[3]]])
-                #         iso_pairs_id['minor_transcript'].append(self.transcript_id[idxs[ids]])
-                #         iso_pairs_id['iso_ratio'].append(iso_ratio)
-                #         iso_pairs_id['diff'].append(res_maj[4][ids])
-                #         iso_pairs_id['corr'].append(res_maj[6][ids])
-                #         iso_pairs_id['final_sp'].append(res_maj[5][ids])
-                #         iso_dict_info[self.transcript_id[idxs[res_maj[3]]]] = (gene, res_maj[3])
-                #         iso_dict_info[self.transcript_id[idxs[ids]]] = (gene, ids)
 
                 for ids1, iso_ratio0 in enumerate(res_maj[0]):
                     for ids2, iso_ratio in enumerate(iso_ratio0):
@@ -725,7 +707,11 @@ class iso_function():
             iso_pairs_id['p_value'] = pval
 
             self.isopairs = iso_pairs_id
-
+        
+        if pd.DataFrame(iso_pairs_id).shape[0]==0:
+            print("We didn't found any significant switch.")
+            return None 
+        
         res = pd.DataFrame(iso_pairs_id).sort_values('p_value')
         mct = pvalue_correction(res['p_value'], method=adjustp)
         res['adj_pval'] = mct.corrected_pvals
